==> tomee-project-8.0.9-source-release.zip: tomee-project-8.0.9/examples/mp-rest-jwt-jwk/src/main/java/org/superbiz/service/ProductService.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.superbiz.service;

import org.superbiz.entity.Product;

import javax.annotation.PostConstruct;
import javax.enterprise.context.ApplicationScoped;
import java.util.*;

@ApplicationScoped
public class ProductService {

    private Map<Integer, Product> productsInStore;

    @PostConstruct
    public void ProductService() {
        productsInStore = new HashMap();
    }

    public List<Product> getProducts() {
        return new ArrayList<>(productsInStore.values());
    }

    public Product getProduct(int id) {
        return productsInStore.get(id);
    }

    public Product addProduct(Product product) {
        productsInStore.put(product.getId(), product);

        return product;
    }

    public void deleteProduct(int id) {
        productsInStore.remove(id);
    }

    public void updateProduct(Product product) {
        productsInStore.put(product.getId(), product);
    }
}

==> tomee-project-10.1.4-source-release.zip: tomee-project-10.1.4/examples/mp-rest-jwt-jwk/src/main/java/org/superbiz/service/ProductService.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.superbiz.service;

import org.superbiz.entity.Product;

import jakarta.annotation.PostConstruct;
import jakarta.enterprise.context.ApplicationScoped;
import java.util.*;

@ApplicationScoped
public class ProductService {

    private Map<Integer, Product> productsInStore;

    @PostConstruct
    public void ProductService() {
        productsInStore = new HashMap();
    }

    public List<Product> getProducts() {
        return new ArrayList<>(productsInStore.values());
    }

    public Product getProduct(int id) {
        return productsInStore.get(id);
    }

    public Product addProduct(Product product) {
        productsInStore.put(product.getId(), product);

        return product;
    }

    public void deleteProduct(int id) {
        productsInStore.remove(id);
    }

    public void updateProduct(Product product) {
        productsInStore.put(product.getId(), product);
    }
}
